@@ -170,7 +170,12 @@ impl UnixTimeStamp {
         Ok(Self(seconds))
     }
 
-    /// Return `None` if `SystemTime` cannot hold the timestamp.
+    /// Return unix epoch, same as [`UnixTimeStamp::default`]
+    pub const fn unix_epoch() -> Self {
+        Self(0)
+    }
+
+    /// Return `None` if [`std::time::SystemTime`] cannot hold the timestamp.
     pub fn from_raw(elapsed: u32) -> Option<Self> {
         let this = Self(elapsed);
 
@@ -245,9 +250,19 @@ impl PartialEq for FileAttrs {
 impl Eq for FileAttrs {}
 
 impl FileAttrs {
-    #[inline]
-    pub fn new() -> Self {
-        Self::default()
+    pub const fn new() -> Self {
+        Self {
+            flags: FileAttrsFlags::empty(),
+            size: 0,
+
+            uid: 0,
+            gid: 0,
+
+            st_mode: 0,
+
+            atime: UnixTimeStamp::unix_epoch(),
+            mtime: UnixTimeStamp::unix_epoch(),
+        }
     }
 
     pub fn set_size(&mut self, size: u64) {
@@ -417,8 +432,8 @@ impl Default for FileAttrsBox {
 
 impl FileAttrsBox {
     /// Return a shared arena that can be used to allocate
-    /// `FileAttrs` efficiently.
-    pub fn get_shared_arena() -> &'static SharedArena<FileAttrs> {
+    /// [`FileAttrs`] efficiently.
+    fn get_shared_arena() -> &'static SharedArena<FileAttrs> {
         static ARENA: OnceCell<SharedArena<FileAttrs>> = OnceCell::new();
 
         ARENA.get_or_init(SharedArena::new)
