@@ -1,7 +1,6 @@
 #![forbid(unsafe_code)]
 
 pub extern crate serde;
-pub extern crate shared_arena;
 pub extern crate ssh_format;
 pub extern crate vec_strings;
 
@@ -10,6 +9,7 @@ mod visitor;
 
 pub mod constants;
 pub mod file_attrs;
+pub mod open_options;
 pub mod request;
 pub mod response;
 
